@@ -13,7 +13,6 @@ import (
 	"github.com/helmwave/helmwave/pkg/hooks"
 	"github.com/helmwave/helmwave/pkg/plan"
 	"github.com/helmwave/helmwave/pkg/release"
-	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/helmwave/helmwave/pkg/repo"
 	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
@@ -158,10 +157,10 @@ func (ts *BuildTestSuite) TestNonUniqueReleases() {
 
 	var e *release.DuplicateError
 	ts.Require().ErrorAs(sfail.Run(ts.ctx), &e)
-	ts.Equal(uniqname.UniqName("nginx@test"), e.Uniq)
+	ts.Equal("nginx@test", e.Uniq.String())
 
 	ts.Require().ErrorAs(sfailByTag.Run(ts.ctx), &e)
-	ts.Equal(uniqname.UniqName("nginx@test"), e.Uniq)
+	ts.Equal("nginx@test", e.Uniq.String())
 
 	ts.Require().NoError(sa.Run(ts.ctx))
 	ts.Require().NoError(sb.Run(ts.ctx))
@@ -437,16 +436,14 @@ func (ts *NonParallelBuildTestSuite) TestRemoteSource() {
 	}
 
 	s := &Build{
-		plandir: plan.Dir,
-		tags:    cli.StringSlice{},
-		options: plan.BuildOptions{
-			MatchAll: true,
-		},
-		remoteSource: "github.com/helmwave/helmwave",
+		plandir:      plan.Dir,
+		tags:         cli.StringSlice{},
+		options:      plan.BuildOptions{},
+		remoteSource: "github.com/helmwave/helmwave/.",
 		yml:          y,
 	}
 
-	cache.DefaultConfig.Home = ts.T().TempDir()
+	cache.Default.Home = ts.T().TempDir()
 
 	err = s.Run(ts.ctx)
 	ts.Require().NoError(err)
