@@ -9,6 +9,7 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/databus23/helm-diff/v3/diff"
 	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	log "github.com/sirupsen/logrus"
@@ -20,6 +21,8 @@ var buf bytes.Buffer
 
 type DiffLocalTestSuite struct {
 	suite.Suite
+
+	ctx context.Context
 }
 
 //nolint:paralleltest // we capture output for global logger and uses helm repository.yaml flock
@@ -29,11 +32,12 @@ func TestDiffLocalTestSuite(t *testing.T) {
 }
 
 func (ts *DiffLocalTestSuite) SetupTest() {
-	log.StandardLogger().SetOutput(&buf)
-}
+	ts.ctx = tests.GetContext(ts.T())
 
-func (ts *DiffLocalTestSuite) TearDownTest() {
-	log.StandardLogger().SetOutput(os.Stderr)
+	log.StandardLogger().SetOutput(&buf)
+	ts.T().Cleanup(func() {
+		log.StandardLogger().SetOutput(os.Stderr)
+	})
 }
 
 func (ts *DiffLocalTestSuite) TestCmd() {
@@ -53,7 +57,7 @@ func (ts *DiffLocalTestSuite) TestRun() {
 			file:      filepath.Join(tests.Root, "02_helmwave.yml"),
 			templater: template.TemplaterSprig,
 		},
-		diff:     &Diff{},
+		diff:     &Diff{Options: &diff.Options{}},
 		diffMode: DiffModeLive,
 	}
 
@@ -65,19 +69,19 @@ func (ts *DiffLocalTestSuite) TestRun() {
 			file:      filepath.Join(tests.Root, "03_helmwave.yml"),
 			templater: template.TemplaterSprig,
 		},
-		diff:     &Diff{},
+		diff:     &Diff{Options: &diff.Options{}},
 		diffMode: DiffModeLive,
 	}
 
 	d := DiffLocal{diff: s1.diff, plandir1: s1.plandir, plandir2: s2.plandir}
 
-	ts.Require().ErrorIs(d.Run(context.Background()), os.ErrNotExist)
-	ts.Require().NoError(s1.Run(context.Background()))
-	ts.Require().ErrorIs(d.Run(context.Background()), os.ErrNotExist)
-	ts.Require().NoError(s2.Run(context.Background()))
+	ts.Require().ErrorIs(d.Run(ts.ctx), os.ErrNotExist)
+	ts.Require().NoError(s1.Run(ts.ctx))
+	ts.Require().ErrorIs(d.Run(ts.ctx), os.ErrNotExist)
+	ts.Require().NoError(s2.Run(ts.ctx))
 
 	buf.Reset()
-	ts.Require().NoError(d.Run(context.Background()))
+	ts.Require().NoError(d.Run(ts.ctx))
 
 	output := buf.String()
 	buf.Reset()
