@@ -4,6 +4,7 @@ import (
 	"context"
 
 	"github.com/helmwave/helmwave/pkg/plan"
+	log "github.com/sirupsen/logrus"
 	"github.com/urfave/cli/v2"
 )
 
@@ -23,6 +24,11 @@ func (i *Down) Run(ctx context.Context) error {
 		}
 	}
 
+	if i.build.skipUnchanged {
+		log.Warn("I can't use HELMWAVE_SKIP_UNCHANGED=true for down command. I've changed it to false")
+		i.build.skipUnchanged = false
+	}
+
 	p, err := plan.NewAndImport(ctx, i.build.plandir)
 	if err != nil {
 		return err
