@@ -17,6 +17,8 @@ import (
 
 type DownTestSuite struct {
 	suite.Suite
+
+	ctx context.Context
 }
 
 //nolint:paralleltest // uses helm repository.yaml flock
@@ -25,6 +27,10 @@ func TestDownTestSuite(t *testing.T) {
 	suite.Run(t, new(DownTestSuite))
 }
 
+func (ts *DownTestSuite) SetupTest() {
+	ts.ctx = tests.GetContext(ts.T())
+}
+
 func (ts *DownTestSuite) TestCmd() {
 	s := &Down{}
 	cmd := s.Cmd()
@@ -51,14 +57,46 @@ func (ts *DownTestSuite) TestRun() {
 	d := Down{
 		build: s,
 	}
-	ts.Require().ErrorIs(d.Run(context.Background()), os.ErrNotExist, "down should fail before build")
-	ts.Require().NoError(s.Run(context.Background()))
+	ts.Require().ErrorIs(d.Run(ts.ctx), os.ErrNotExist, "down should fail before build")
+	ts.Require().NoError(s.Run(ts.ctx))
 
 	u := &Up{
 		build: s,
 		dog:   &kubedog.Config{},
 	}
 
-	ts.Require().NoError(u.Run(context.Background()))
-	ts.Require().NoError(d.Run(context.Background()))
+	ts.Require().NoError(u.Run(ts.ctx))
+	ts.Require().NoError(d.Run(ts.ctx))
+}
+
+func (ts *DownTestSuite) TestIdempotency() {
+	tmpDir := ts.T().TempDir()
+	y := &Yml{
+		tpl:       filepath.Join(tests.Root, "02_helmwave.yml"),
+		file:      filepath.Join(tests.Root, "02_helmwave.yml"),
+		templater: template.TemplaterSprig,
+	}
+
+	s := &Build{
+		plandir: tmpDir,
+		tags:    cli.StringSlice{},
+		autoYml: true,
+		yml:     y,
+	}
+
+	u := &Up{
+		build: s,
+		dog:   &kubedog.Config{},
+	}
+	d := Down{
+		build: s,
+	}
+
+	ctx, cancel := context.WithCancel(ts.ctx)
+	ts.T().Cleanup(cancel)
+
+	ts.Require().NoError(s.Run(ctx))
+	ts.Require().NoError(u.Run(ctx))
+	ts.Require().NoError(d.Run(ctx))
+	ts.Require().NoError(d.Run(ctx))
 }
