@@ -15,7 +15,7 @@ var _ Action = (*GenSchema)(nil)
 type GenSchema struct{}
 
 // Run is the main function for 'GenSchema' command.
-func (i *GenSchema) Run(ctx context.Context) error {
+func (i *GenSchema) Run(_ context.Context) error {
 	s, err := json.Marshal(plan.GenSchema())
 	if err != nil {
 		return err
@@ -29,10 +29,11 @@ func (i *GenSchema) Run(ctx context.Context) error {
 // Cmd returns 'GenSchema' *cli.Command.
 func (i *GenSchema) Cmd() *cli.Command {
 	return &cli.Command{
-		Name:   "schema",
-		Usage:  "generate json schema",
-		Flags:  i.flags(),
-		Action: toCtx(i.Run),
+		Name:     "schema",
+		Category: Step_,
+		Usage:    "generate json schema",
+		Flags:    i.flags(),
+		Action:   toCtx(i.Run),
 	}
 }
 
