@@ -78,15 +78,9 @@ func (i *Up) flags() []cli.Flag {
 			Usage:       "enable progress logs of helm (INFO log level)",
 			Value:       false,
 			Category:    "KUBEDOG",
-			EnvVars:     []string{"HELMWAVE_PROGRESS"},
+			EnvVars:     EnvVars("PROGRESS"),
 			Destination: &helper.Helm.Debug,
 		},
-		&cli.IntFlag{
-			Name:    "parallel-limit",
-			Usage:   "limit amount of parallel releases",
-			EnvVars: []string{"HELMWAVE_PARALLEL_LIMIT"},
-			Value:   0,
-		},
 	}
 
 	self = append(self, flagsKubedog(i.dog)...)
