@@ -18,7 +18,7 @@ type Yml struct {
 
 // Run is the main function for 'yml' command.
 func (i *Yml) Run(ctx context.Context) error {
-	err := template.Tpl2yml(i.tpl, i.file, nil, i.templater)
+	err := template.Tpl2yml(ctx, i.tpl, i.file, nil, i.templater)
 	if err != nil {
 		return err
 	}
@@ -34,7 +34,8 @@ func (i *Yml) Run(ctx context.Context) error {
 // Cmd returns 'yml' *cli.Command.
 func (i *Yml) Cmd() *cli.Command {
 	return &cli.Command{
-		Name:   "yml",
+		Name: "yml",
+		// Category: Step0,
 		Usage:  "📄 render helmwave.yml.tpl -> helmwave.yml",
 		Flags:  i.flags(),
 		Action: toCtx(i.Run),
