@@ -10,17 +10,6 @@ import (
 	log "github.com/sirupsen/logrus"
 )
 
-// Contains checks whether string exists in string slice.
-func Contains(t string, a []string) bool {
-	for _, v := range a {
-		if v == t {
-			return true
-		}
-	}
-
-	return false
-}
-
 // CreateFile creates recursively basedir of file and returns created file object.
 func CreateFile(p string) (*os.File, error) {
 	if err := os.MkdirAll(filepath.Dir(p), 0o755); err != nil {
