@@ -23,15 +23,6 @@ func (err CreatePipeError) Unwrap() error {
 	return err.Err
 }
 
-func (CreatePipeError) Is(target error) bool {
-	switch target.(type) {
-	case CreatePipeError, *CreatePipeError:
-		return true
-	default:
-		return false
-	}
-}
-
 type CommandRunError struct {
 	Err error
 }
@@ -48,15 +39,6 @@ func (err CommandRunError) Unwrap() error {
 	return err.Err
 }
 
-func (CommandRunError) Is(target error) bool {
-	switch target.(type) {
-	case CommandRunError, *CommandRunError:
-		return true
-	default:
-		return false
-	}
-}
-
 type CommandReadOutputError struct {
 	Err error
 }
@@ -73,15 +55,6 @@ func (err CommandReadOutputError) Unwrap() error {
 	return err.Err
 }
 
-func (CommandReadOutputError) Is(target error) bool {
-	switch target.(type) {
-	case CommandReadOutputError, *CommandReadOutputError:
-		return true
-	default:
-		return false
-	}
-}
-
 type YAMLDecodeError struct {
 	Err error
 }
@@ -97,12 +70,3 @@ func (err YAMLDecodeError) Error() string {
 func (err YAMLDecodeError) Unwrap() error {
 	return err.Err
 }
-
-func (YAMLDecodeError) Is(target error) bool {
-	switch target.(type) {
-	case YAMLDecodeError, *YAMLDecodeError:
-		return true
-	default:
-		return false
-	}
-}
