@@ -1,6 +1,7 @@
 package plan
 
 import (
+	"context"
 	"slices"
 
 	"github.com/helmwave/helmwave/pkg/helper"
@@ -8,16 +9,23 @@ import (
 	log "github.com/sirupsen/logrus"
 )
 
-func (p *Plan) buildReleases(tags []string, matchAll bool) ([]release.Config, error) {
+func (p *Plan) buildReleases(ctx context.Context, o BuildOptions) ([]release.Config, error) {
+	log.Info("🔨 Building releases...")
+
 	plan := make([]release.Config, 0)
 
+	planAdderFunction := addToPlanWithDependencies
+	if !o.EnableDependencies {
+		planAdderFunction = addToPlanWithoutDependencies
+	}
+
 	for _, r := range p.body.Releases {
-		if !checkTagInclusion(tags, r.Tags(), matchAll) {
+		if !checkTagInclusion(o.Tags, r.Tags(), o.MatchAll) {
 			continue
 		}
 
 		var err error
-		plan, err = addToPlan(plan, r, p.body.Releases)
+		plan, err = planAdderFunction(plan, r, p.body.Releases)
 		if err != nil {
 			log.WithError(err).Error("failed to build releases plan")
 
@@ -25,14 +33,23 @@ func (p *Plan) buildReleases(tags []string, matchAll bool) ([]release.Config, er
 		}
 	}
 
+	// Run per-release build hook (in dependency order)
+	for _, r := range plan {
+		// Run hooks
+		lifecycle := r.Lifecycle()
+		err := lifecycle.RunPreBuild(ctx)
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	return plan, nil
 }
 
 func addToPlan(
 	plan release.Configs,
 	rel release.Config,
-	releases release.Configs,
-) (release.Configs, error) {
+) (_ release.Configs, err error) {
 	if r, contains := plan.Contains(rel); contains {
 		if r != rel {
 			return nil, release.NewDuplicateError(rel.Uniq())
@@ -41,8 +58,33 @@ func addToPlan(
 		}
 	}
 
-	newPlan := plan
-	newPlan = append(newPlan, rel)
+	return append(plan, rel), nil
+}
+
+func addToPlanWithoutDependencies(
+	plan release.Configs,
+	rel release.Config,
+	_ release.Configs,
+) (release.Configs, error) {
+	plan, err := addToPlan(plan, rel)
+	if err != nil {
+		return nil, err
+	}
+
+	rel.SetDependsOn([]*release.DependsOnReference{})
+
+	return plan, nil
+}
+
+func addToPlanWithDependencies(
+	plan release.Configs,
+	rel release.Config,
+	releases release.Configs,
+) (release.Configs, error) {
+	newPlan, err := addToPlan(plan, rel)
+	if err != nil {
+		return nil, err
+	}
 
 	deps := rel.DependsOn()
 	newDeps := make([]*release.DependsOnReference, 0, len(deps))
@@ -54,7 +96,7 @@ func addToPlan(
 		r, found := releases.ContainsUniq(dep.Uniq())
 		if found {
 			var err error
-			newPlan, err = addToPlan(newPlan, r, releases)
+			newPlan, err = addToPlanWithDependencies(newPlan, r, releases)
 			if err != nil {
 				return nil, err
 			}
