@@ -34,14 +34,15 @@ func (ts *BuildRepositoriesTestSuite) TestLocalRepo() {
 
 	repoName := ts.T().Name()
 
-	mockedRelease := &MockReleaseConfig{}
+	mockedRelease := NewMockReleaseConfig(ts.T())
 	mockedRelease.On("Name").Return("redis")
 	mockedRelease.On("Repo").Return(repoName)
 	mockedRelease.On("Namespace").Return("defaultblabla")
 	mockedRelease.On("Uniq").Return()
 	mockedRelease.On("Chart").Return(&release.Chart{})
+	mockedRelease.On("KubeContext").Return("")
 
-	mockedRepo := &MockRepositoryConfig{}
+	mockedRepo := NewMockRepositoryConfig(ts.T())
 	mockedRepo.On("Name").Return(repoName)
 
 	p.SetRepositories(mockedRepo)
@@ -60,7 +61,7 @@ func (ts *BuildRepositoriesTestSuite) TestUnusedRepo() {
 	tmpDir := ts.T().TempDir()
 	p := New(filepath.Join(tmpDir, Dir))
 
-	mockedRepo := &MockRepositoryConfig{}
+	mockedRepo := NewMockRepositoryConfig(ts.T())
 
 	p.SetRepositories(mockedRepo)
 
@@ -77,14 +78,15 @@ func (ts *BuildRepositoriesTestSuite) TestSuccess() {
 
 	repoName := "blablanami"
 
-	mockedRelease := &MockReleaseConfig{}
+	mockedRelease := NewMockReleaseConfig(ts.T())
 	mockedRelease.On("Name").Return("redis")
 	mockedRelease.On("Repo").Return(repoName)
 	mockedRelease.On("Namespace").Return("defaultblabla")
 	mockedRelease.On("Uniq").Return()
 	mockedRelease.On("Chart").Return(&release.Chart{})
+	mockedRelease.On("KubeContext").Return("")
 
-	mockedRepo := &MockRepositoryConfig{}
+	mockedRepo := NewMockRepositoryConfig(ts.T())
 	mockedRepo.On("Name").Return(repoName)
 
 	p.SetRepositories(mockedRepo)
@@ -105,12 +107,13 @@ func (ts *BuildRepositoriesTestSuite) TestMissingRepo() {
 
 	repoName := "blablanami"
 
-	mockedRelease := &MockReleaseConfig{}
+	mockedRelease := NewMockReleaseConfig(ts.T())
 	mockedRelease.On("Name").Return("redis")
 	mockedRelease.On("Repo").Return(repoName)
 	mockedRelease.On("Namespace").Return("defaultblabla")
 	mockedRelease.On("Uniq").Return()
 	mockedRelease.On("Chart").Return(&release.Chart{})
+	mockedRelease.On("KubeContext").Return("")
 
 	p.SetReleases(mockedRelease)
 
