@@ -11,10 +11,18 @@ import (
 	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/parallel"
 	"github.com/helmwave/helmwave/pkg/release"
+	log "github.com/sirupsen/logrus"
 )
 
 // Export allows save plan to file.
 func (p *Plan) Export(ctx context.Context, skipUnchanged bool) error {
+	wd, err := os.Getwd()
+	if err != nil {
+		return fmt.Errorf("failed to get current directory: %w", err)
+	}
+
+	log.Tracef("I am exporting plan to %s", filepath.Join(wd, p.dir))
+
 	if err := os.RemoveAll(p.dir); err != nil {
 		return fmt.Errorf("failed to clean plan directory %s: %w", p.dir, err)
 	}
@@ -58,7 +66,7 @@ func (p *Plan) Export(ctx context.Context, skipUnchanged bool) error {
 		}
 	}()
 
-	err := wg.Wait()
+	err = wg.Wait()
 	if err != nil {
 		return err
 	}
@@ -180,7 +188,7 @@ func (p *Plan) exportValues() error {
 		return nil
 	}
 
-	// It doesnt work if workdir has been mounted.
+	// It doesn't work if workdir has been mounted.
 	err := helper.MoveFile(
 		filepath.Join(p.tmpDir, Values),
 		filepath.Join(p.dir, Values),
