@@ -7,7 +7,6 @@ import (
 	"github.com/helmwave/helmwave/pkg/kubedog"
 	"github.com/helmwave/helmwave/pkg/release"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
-	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/suite"
 	helmRelease "helm.sh/helm/v3/pkg/release"
 )
@@ -41,7 +40,8 @@ func (s *KubedogTestSuite) TestCallsManifestFunction() {
 	p := New("")
 	p.NewBody()
 
-	rel := &MockReleaseConfig{}
+	rel := NewMockReleaseConfig(s.T())
+	rel.On("KubeContext").Return("")
 	p.SetReleases(rel)
 
 	s.Require().Panics(func() {
@@ -56,7 +56,7 @@ func (s *KubedogTestSuite) TestSyncSpecs() {
 	relName := "bla"
 	relNS := "blabla"
 	kubecontext := "blacontext"
-	u, _ := uniqname.Generate(relName, relNS)
+	u, _ := uniqname.New(relName, relNS, "")
 
 	p.manifests[u] = `
 kind: Canary
@@ -86,11 +86,10 @@ metadata:
 ---
 `
 
-	mockedRelease := &MockReleaseConfig{}
+	mockedRelease := NewMockReleaseConfig(s.T())
 	mockedRelease.On("KubeContext").Return(kubecontext)
 	mockedRelease.On("Uniq").Return(u)
 	mockedRelease.On("Namespace").Return(relNS)
-	mockedRelease.On("Logger").Return(log.WithField("test", s.T().Name()))
 	p.SetReleases(mockedRelease)
 
 	spec, context, err := p.kubedogSyncSpecs(&kubedog.Config{TrackGeneric: true})
@@ -117,7 +116,7 @@ func (s *KubedogTestSuite) TestRollbackSpecs() {
 	relNS := "blabla"
 	kubecontext := "blacontext"
 	version := 666
-	u, _ := uniqname.Generate(relName, relNS)
+	u, _ := uniqname.New(relName, relNS, "")
 
 	manifest := `
 kind: Canary
@@ -147,11 +146,10 @@ metadata:
 ---
 `
 
-	mockedRelease := &MockReleaseConfig{}
+	mockedRelease := NewMockReleaseConfig(s.T())
 	mockedRelease.On("KubeContext").Return(kubecontext)
 	mockedRelease.On("Uniq").Return(u)
 	mockedRelease.On("Namespace").Return(relNS)
-	mockedRelease.On("Logger").Return(log.WithField("test", s.T().Name()))
 	mockedRelease.On("Get", version).Return(&helmRelease.Release{Manifest: manifest}, nil)
 	p.SetReleases(mockedRelease)
 
@@ -179,9 +177,8 @@ func (s *KubedogTestSuite) TestRollbackSpecsGetError() {
 	version := 666
 	errExpected := errors.New("test error")
 
-	mockedRelease := &MockReleaseConfig{}
+	mockedRelease := NewMockReleaseConfig(s.T())
 	mockedRelease.On("KubeContext").Return(kubecontext)
-	mockedRelease.On("Logger").Return(log.WithField("test", s.T().Name()))
 	mockedRelease.On("Get", version).Return((*helmRelease.Release)(nil), errExpected)
 	p.SetReleases(mockedRelease)
 
@@ -197,19 +194,17 @@ func (s *KubedogTestSuite) TestSpecsMultipleContexts() {
 
 	relName := "bla"
 	relNS := "blabla"
-	u, _ := uniqname.Generate(relName, relNS)
+	u, _ := uniqname.New(relName, relNS, "")
 
-	mockedRelease1 := &MockReleaseConfig{}
+	mockedRelease1 := NewMockReleaseConfig(s.T())
 	mockedRelease1.On("KubeContext").Return("bla1")
 	mockedRelease1.On("Uniq").Return(u)
 	mockedRelease1.On("Namespace").Return(relNS)
-	mockedRelease1.On("Logger").Return(log.WithField("test", s.T().Name()))
 
-	mockedRelease2 := &MockReleaseConfig{}
+	mockedRelease2 := NewMockReleaseConfig(s.T())
 	mockedRelease2.On("KubeContext").Return("bla2")
 	mockedRelease2.On("Uniq").Return(u)
 	mockedRelease2.On("Namespace").Return(relNS)
-	mockedRelease2.On("Logger").Return(log.WithField("test", s.T().Name()))
 
 	p.SetReleases(mockedRelease1, mockedRelease2)
 
