@@ -1,6 +1,8 @@
 package plan
 
 import (
+	"testing"
+
 	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/mock"
 )
@@ -9,6 +11,15 @@ type MockRegistryConfig struct {
 	mock.Mock
 }
 
+func NewMockRegistryConfig(t *testing.T) *MockRegistryConfig {
+	t.Helper()
+
+	c := &MockRegistryConfig{}
+	c.Mock.Test(t)
+
+	return c
+}
+
 func (r *MockRegistryConfig) Install() error {
 	return r.Called().Error(0)
 }
