@@ -3,20 +3,39 @@ package plan
 import (
 	"context"
 	"path/filepath"
+	"testing"
 
+	"github.com/helmwave/helmwave/pkg/hooks"
 	"github.com/helmwave/helmwave/pkg/monitor"
 	"github.com/helmwave/helmwave/pkg/release"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/helmwave/helmwave/pkg/template"
-	"github.com/sirupsen/logrus"
+	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/mock"
 	"helm.sh/helm/v3/pkg/action"
 	"helm.sh/helm/v3/pkg/chartutil"
 	helmRelease "helm.sh/helm/v3/pkg/release"
 )
 
+//nolint:govet // field alignment doesn't matter in tests
 type MockReleaseConfig struct {
 	mock.Mock
+
+	t *testing.T
+}
+
+func NewMockReleaseConfig(t *testing.T) *MockReleaseConfig {
+	t.Helper()
+
+	c := &MockReleaseConfig{}
+	c.Mock.Test(t)
+	c.t = t
+
+	return c
+}
+
+func (r *MockReleaseConfig) HideSecret(_ bool) {
+	r.Called()
 }
 
 func (r *MockReleaseConfig) SetChartName(_ string) {
@@ -42,7 +61,7 @@ func (r *MockReleaseConfig) Uniq() uniqname.UniqName {
 		return args.Get(0).(uniqname.UniqName)
 	}
 
-	u, _ := uniqname.Generate(r.Name(), r.Namespace())
+	u, _ := uniqname.New(r.Name(), r.Namespace(), r.KubeContext())
 
 	return u
 }
@@ -150,8 +169,8 @@ func (r *MockReleaseConfig) Values() []release.ValuesReference {
 	return r.Called().Get(0).([]release.ValuesReference)
 }
 
-func (r *MockReleaseConfig) Logger() *logrus.Entry {
-	return r.Called().Get(0).(*logrus.Entry)
+func (r *MockReleaseConfig) Logger() *log.Entry {
+	return log.WithField("test", r.t.Name())
 }
 
 func (r *MockReleaseConfig) AllowFailure() bool {
@@ -191,3 +210,7 @@ func (r *MockReleaseConfig) Monitors() []release.MonitorReference {
 func (r *MockReleaseConfig) NotifyMonitorsFailed(context.Context, ...monitor.Config) {
 	r.Called()
 }
+
+func (r *MockReleaseConfig) Lifecycle() hooks.Lifecycle {
+	return r.Called().Get(0).(hooks.Lifecycle)
+}
