@@ -2,6 +2,7 @@ package plan
 
 import (
 	"context"
+	"testing"
 
 	"github.com/helmwave/helmwave/pkg/repo"
 	"github.com/sirupsen/logrus"
@@ -14,6 +15,15 @@ type MockRepositoryConfig struct {
 	mock.Mock
 }
 
+func NewMockRepositoryConfig(t *testing.T) *MockRepositoryConfig {
+	t.Helper()
+
+	c := &MockRepositoryConfig{}
+	c.Mock.Test(t)
+
+	return c
+}
+
 func (r *MockRepositoryConfig) Equal(_ repo.Config) bool {
 	return r.Called().Bool(0)
 }
