@@ -13,7 +13,6 @@ import (
 	"github.com/helmwave/helmwave/pkg/plan"
 	"github.com/helmwave/helmwave/pkg/release"
 	"github.com/helmwave/helmwave/pkg/template"
-	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/suite"
 )
 
@@ -39,7 +38,7 @@ func (ts *ValidateTestSuite) TestInvalidRelease() {
 
 	err := errors.New("test error")
 
-	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease := plan.NewMockReleaseConfig(ts.T())
 	mockedRelease.On("Validate").Return(err)
 
 	p.SetReleases(mockedRelease)
@@ -57,7 +56,7 @@ func (ts *ValidateTestSuite) TestInvalidRepository() {
 
 	err := errors.New("test error")
 
-	mockedRepo := &plan.MockRepositoryConfig{}
+	mockedRepo := plan.NewMockRepositoryConfig(ts.T())
 	mockedRepo.On("Validate").Return(err)
 
 	p.SetRepositories(mockedRepo)
@@ -76,13 +75,15 @@ func (ts *ValidateTestSuite) TestValidateValues() {
 	tmpValues := filepath.Join(tmpDir, "valuesName")
 	ts.Require().NoError(os.WriteFile(tmpValues, valuesContents, 0o600))
 
-	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease := plan.NewMockReleaseConfig(ts.T())
 	mockedRelease.On("Name").Return(ts.T().Name())
 	mockedRelease.On("Namespace").Return(ts.T().Name())
 	mockedRelease.On("Uniq").Return()
-	mockedRelease.On("Logger").Return(log.WithField("test", ts.T().Name()))
+	mockedRelease.On("KubeContext").Return("")
+
 	v := release.ValuesReference{Src: tmpValues}
 	ts.Require().NoError(v.SetViaRelease(ts.ctx, mockedRelease, tmpDir, template.TemplaterSprig, nil))
+
 	mockedRelease.On("Values").Return([]release.ValuesReference{v})
 
 	p.SetReleases(mockedRelease)
@@ -100,8 +101,7 @@ func (ts *ValidateTestSuite) TestValidateValuesNotFound() {
 	tmpValues := filepath.Join(tmpDir, "valuesName")
 	ts.Require().NoError(os.WriteFile(tmpValues, valuesContents, 0o600))
 
-	mockedRelease := &plan.MockReleaseConfig{}
-	mockedRelease.On("Logger").Return(log.WithField("test", ts.T().Name()))
+	mockedRelease := plan.NewMockReleaseConfig(ts.T())
 	v := release.ValuesReference{Src: tmpValues}
 	mockedRelease.On("Values").Return([]release.ValuesReference{v})
 
@@ -126,7 +126,7 @@ func (ts *ValidateTestSuite) TestValidateRepositoryDuplicate() {
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 	body := p.NewBody()
 
-	mockedRepo := &plan.MockRepositoryConfig{}
+	mockedRepo := plan.NewMockRepositoryConfig(ts.T())
 	mockedRepo.On("Name").Return("blabla")
 	mockedRepo.On("Validate").Return(nil)
 
@@ -148,11 +148,12 @@ func (ts *ValidateTestSuite) TestValidateReleaseDuplicate() {
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 	body := p.NewBody()
 
-	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease := plan.NewMockReleaseConfig(ts.T())
 	mockedRelease.On("Name").Return("blabla")
 	mockedRelease.On("Namespace").Return("defaultblabla")
 	mockedRelease.On("Uniq").Return()
 	mockedRelease.On("Validate").Return(nil)
+	mockedRelease.On("KubeContext").Return("")
 
 	p.SetReleases(mockedRelease, mockedRelease)
 
