@@ -42,7 +42,7 @@ func (ts *InterfaceTestSuite) TestUnmarshalYAML() {
 
 	ts.Require().NoError(err)
 	ts.Require().Len(cfgs, 1)
-	ts.Require().Equal(cfgs[0].Host(), "blabla")
+	ts.Require().Equal("blabla", cfgs[0].Host())
 }
 
 func (ts *InterfaceTestSuite) TestUnmarshalYAMLInvalid() {
@@ -51,5 +51,6 @@ func (ts *InterfaceTestSuite) TestUnmarshalYAMLInvalid() {
 
 	err := yaml.Unmarshal([]byte(str), &cfgs)
 
-	ts.Require().ErrorIs(err, registry.YAMLDecodeError{})
+	var e *registry.YAMLDecodeError
+	ts.Require().ErrorAs(err, &e)
 }
