@@ -5,6 +5,7 @@ import (
 	"sync"
 	"time"
 
+	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/hooks"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	log "github.com/sirupsen/logrus"
@@ -23,7 +24,7 @@ type config struct {
 	helm *helm.EnvSettings
 	log  *log.Entry
 
-	Lifecycle              hooks.Lifecycle `yaml:"lifecycle,omitempty" json:"lifecycle,omitempty" jsonschema:"description=Lifecycle hooks"`
+	LifecycleF             hooks.Lifecycle `yaml:"lifecycle,omitempty" json:"lifecycle,omitempty" jsonschema:"description=Lifecycle hooks"`
 	Store                  map[string]any  `yaml:"store,omitempty" json:"store,omitempty" jsonschema:"title=The Store,description=It allows to pass your custom fields from helmwave.yml to values"`
 	ChartF                 Chart           `yaml:"chart,omitempty" json:"chart,omitempty" jsonschema:"title=Chart reference,description=Describes chart that release uses,oneof_type=string;object"`
 	Tests                  configTests     `yaml:"tests,omitempty" json:"tests,omitempty" jsonschema:"description=Configuration for helm tests"`
@@ -61,14 +62,25 @@ type config struct {
 	ResetValues              bool `yaml:"reset_values,omitempty" json:"reset_values,omitempty" jsonschema:"default=false"`
 	ReuseValues              bool `yaml:"reuse_values,omitempty" json:"reuse_values,omitempty" jsonschema:"default=false"`
 	ResetThenReuseValues     bool `yaml:"reset_then_reuse_values,omitempty" json:"reset_then_reuse_values,omitempty" jsonschema:"default=false"`
-	SkipCRDs                 bool `yaml:"skip_crds,omitempty" json:"skip_crds,omitempty" jsonschema:"default=false"`
-	ShowNotes                bool `yaml:"show_notes,omitempty" json:"show_notes,omitempty" jsonschema:"description=Output rendered chart notes after upgrade/install"`
-	SubNotes                 bool `yaml:"sub_notes,omitempty" json:"sub_notes,omitempty" jsonschema:"default=false"`
+	SkipCRDs                 bool `yaml:"skip_crds,omitempty" json:"skip_crds,omitempty" jsonschema:"description=Skips installing CRDs when install flag is enabled during upgrade,default=false"`
+	HideNotes                bool `yaml:"hide_notes,omitempty" json:"hide_notes,omitempty" jsonschema:"description=Output rendered chart notes after upgrade/install,default=true"`
+	SubNotes                 bool `yaml:"sub_notes,omitempty" json:"sub_notes,omitempty" jsonschema:"description=Determines whether sub-notes are rendered in the chart,default=false"`
 	Wait                     bool `yaml:"wait,omitempty" json:"wait,omitempty" jsonschema:"description=Whether to wait for all resource to become ready,default=false"`
 	WaitForJobs              bool `yaml:"wait_for_jobs,omitempty" json:"wait_for_jobs,omitempty" jsonschema:"description=Whether to wait for all jobs to become ready,default=false"`
+	TakeOwnership            bool `yaml:"take_ownership,omitempty" json:"take_ownership,omitempty" jsonschema:"description=Will ignore the check for helm annotations and take ownership of the resources,default=false"`
+	SkipSchemaValidation     bool `yaml:"skip_schema_validation,omitempty" json:"skip_schema_validation,omitempty" jsonschema:"description=Determines if JSON schema validation is disabled.,default=false"`
 
 	// special field for templating and building
-	dryRun bool `jsonschema:"default=false,-"`
+	dryRun     bool `jsonschema:"default=false,-"`
+	hideSecret bool `jsonschema:"default=false,-"`
+}
+
+// HideSecret can be set to true when DryRun is enabled in order to hide
+// Kubernetes Secrets in the output. It cannot be used outside DryRun.
+func (rel *config) HideSecret(b bool) {
+	if rel.dryRun {
+		rel.hideSecret = b
+	}
 }
 
 func (rel *config) DryRun(b bool) {
@@ -77,13 +89,14 @@ func (rel *config) DryRun(b bool) {
 
 // Uniq like redis@my-namespace.
 func (rel *config) Uniq() uniqname.UniqName {
-	if rel.uniqName == "" {
+	if rel.uniqName.Empty() {
 		var err error
-		rel.uniqName, err = uniqname.Generate(rel.Name(), rel.Namespace())
+		rel.uniqName, err = uniqname.New(rel.Name(), rel.Namespace(), rel.KubeContext())
 		if err != nil {
 			rel.Logger().WithFields(log.Fields{
 				"name":       rel.Name(),
 				"namespace":  rel.Namespace(),
+				"context":    rel.KubeContext(),
 				log.ErrorKey: err,
 			}).Error("failed to generate valid uniqname")
 		}
@@ -161,6 +174,9 @@ func (rel *config) buildAfterUnmarshal(allReleases []*config) {
 		rel.Logger().Debug("timeout is not set, defaulting to 5m")
 		rel.Timeout = 5 * time.Minute
 	}
+
+	// Uniqname is default tag
+	rel.TagsF = append(rel.TagsF, rel.Uniq().String())
 }
 
 func (rel *config) buildAfterUnmarshalDependsOn(allReleases []*config) {
@@ -171,7 +187,9 @@ func (rel *config) buildAfterUnmarshalDependsOn(allReleases []*config) {
 		switch dep.Type() {
 		case DependencyRelease:
 			err := rel.buildAfterUnmarshalDependency(dep)
-			if err == nil {
+			if err != nil {
+				rel.Logger().WithField("dependency", dep).WithError(err).Error("can't parse dependency")
+			} else {
 				newDeps = append(newDeps, dep)
 			}
 		case DependencyTag:
@@ -196,18 +214,22 @@ func (rel *config) buildAfterUnmarshalDependsOn(allReleases []*config) {
 	rel.lock.Unlock()
 }
 
+// buildAfterUnmarshalDependency generates full uniqname for dependency if it was short using release as default.
 func (rel *config) buildAfterUnmarshalDependency(dep *DependsOnReference) error {
-	u, err := uniqname.GenerateWithDefaultNamespace(dep.Name, rel.Namespace())
-	if err != nil {
-		rel.Logger().WithField("dependency", dep).WithError(err).Error("can't parse dependency")
+	// skipping error as it may fail due to missing namespace
+	u, _ := uniqname.NewFromString(dep.Name)
 
-		return err
+	if u.Namespace == "" {
+		u.Namespace = rel.Namespace()
+	}
+
+	if u.Context == "" {
+		u.Context = rel.KubeContext()
 	}
 
-	// generate full uniqname string if it was short
 	dep.Name = u.String()
 
-	return nil
+	return u.Validate()
 }
 
 func (rel *config) PostRenderer() (postrender.PostRenderer, error) {
@@ -219,19 +241,25 @@ func (rel *config) PostRenderer() (postrender.PostRenderer, error) {
 }
 
 func (rel *config) KubeContext() string {
+	if rel.KubeContextF == "" {
+		rel.KubeContextF = helper.Helm.KubeContext
+	}
+
 	return rel.KubeContextF
 }
 
 // MarshalYAML is a marshaller for gopkg.in/yaml.v3.
 // It is required to avoid data race with getting read lock.
+//
+//nolint:govet // we don't care about mutex copying during marshaling
 func (rel *config) MarshalYAML() (any, error) {
 	rel.lock.RLock()
 	defer rel.lock.RUnlock()
 
 	type raw config
-	r := raw(*rel) //nolint:govet
+	r := raw(*rel)
 
-	return r, nil //nolint:govet
+	return r, nil
 }
 
 func (rel *config) HooksDisabled() bool {
@@ -259,3 +287,7 @@ func (rel *config) Monitors() []MonitorReference {
 
 	return rel.MonitorsF
 }
+
+func (rel *config) Lifecycle() hooks.Lifecycle {
+	return rel.LifecycleF
+}
