@@ -1,10 +1,10 @@
 package release_test
 
 import (
+	"slices"
 	"testing"
 
 	"github.com/helmwave/helmwave/pkg/release"
-	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/stretchr/testify/suite"
 )
 
@@ -21,24 +21,32 @@ func (s *ConfigTestSuite) TestConfigUniq() {
 	r := release.NewConfig()
 	r.NameF = "redis"
 	r.NamespaceF = "test"
+	r.KubeContextF = "ctx"
 
 	s.Require().NoError(r.Uniq().Validate())
 }
 
+func (s *ConfigTestSuite) TestConfigUniqTags() {
+	r := release.NewConfig()
+
+	r.BuildAfterUnmarshal()
+
+	s.Require().True(slices.Contains(r.TagsF, r.Uniq().String()))
+}
+
 func (s *ConfigTestSuite) TestConfigInvalidUniq() {
 	r := release.NewConfig()
 	r.NameF = "redis"
 	r.NamespaceF = ""
 
-	var e *uniqname.ValidationError
-	s.Require().ErrorAs(r.Uniq().Validate(), &e)
-	s.Equal(r.Uniq().String(), e.Uniq)
+	s.Require().Error(r.Uniq().Validate())
 }
 
 func (s *ConfigTestSuite) TestDependsOn() {
 	r := release.NewConfig()
 
 	r.NamespaceF = "testns"
+	r.KubeContextF = "testctx"
 	r.DependsOnF = []*release.DependsOnReference{
 		{Name: "bla"},
 		{Name: "blabla@testns"},
@@ -49,9 +57,9 @@ func (s *ConfigTestSuite) TestDependsOn() {
 	r.BuildAfterUnmarshal(r)
 
 	expected := []*release.DependsOnReference{
-		{Name: "bla@testns"},
-		{Name: "blabla@testns"},
-		{Name: "blablabla@testtestns"},
+		{Name: "bla@testns@testctx"},
+		{Name: "blabla@testns@testctx"},
+		{Name: "blablabla@testtestns@testctx"},
 	}
 	s.Require().ElementsMatch(r.DependsOn(), expected)
 }
