@@ -2,10 +2,8 @@ package release
 
 import (
 	"context"
-	"errors"
 
 	"github.com/invopop/jsonschema"
-	"helm.sh/helm/v3/pkg/release"
 )
 
 // PendingStrategy is a type for enumerating strategies for handling pending releases.
@@ -18,9 +16,6 @@ const (
 	PendingStrategyUninstall PendingStrategy = "uninstall"
 )
 
-// ErrPendingRelease is an error for fail strategy that release is in pending status.
-var ErrPendingRelease = errors.New("release is in pending status")
-
 func (PendingStrategy) JSONSchema() *jsonschema.Schema {
 	return &jsonschema.Schema{
 		Type: "string",
@@ -38,12 +33,7 @@ func (rel *config) isPending() (bool, error) {
 		return false, err
 	}
 
-	switch status.Info.Status {
-	case release.StatusPendingInstall, release.StatusPendingRollback, release.StatusPendingUpgrade:
-		return true, nil
-	default:
-		return false, nil
-	}
+	return status.Info.Status.IsPending(), nil
 }
 
 func (rel *config) fixPending(ctx context.Context) error {
