@@ -1,6 +1,7 @@
 package release
 
 import (
+	"bytes"
 	"context"
 	"fmt"
 	"strings"
@@ -23,10 +24,9 @@ func (rel *config) upgrade(ctx context.Context) (*release.Release, error) {
 	}
 
 	// Values
-	valuesFiles := make([]string, 0, len(rel.Values()))
-	for i := range rel.Values() {
-		valuesFiles = append(valuesFiles, rel.Values()[i].Dst)
-	}
+	valuesFiles := helper.SlicesMap(rel.Values(), func(v ValuesReference) string {
+		return v.Dst
+	})
 
 	valOpts := &values.Options{ValueFiles: valuesFiles}
 	vals, err := valOpts.MergeValues(getter.All(rel.Helm()))
@@ -130,3 +130,25 @@ func (rel *config) forceOfflineKubeVersion() error {
 
 	return nil
 }
+
+func (rel *config) test() error {
+	rel.Logger().Info("running helm tests")
+
+	client := rel.newTest()
+	r, err := client.Run(rel.Name())
+
+	if (err != nil) || rel.Tests.ForceShowLogs {
+		var buf bytes.Buffer
+		_ = client.GetPodLogs(&buf, r)
+
+		if err != nil {
+			rel.Logger().WithError(err).WithField("output", buf.String()).Error("helm tests failed")
+
+			return NewHelmTestsError(err)
+		}
+
+		rel.Logger().WithField("output", buf.String()).Info("helm tests output")
+	}
+
+	return nil
+}
