@@ -19,16 +19,7 @@ func NewInvalidURLError(url string) error {
 }
 
 func (err InvalidURLError) Error() string {
-	return fmt.Sprintf("invalid URL: %s", err.URL)
-}
-
-func (InvalidURLError) Is(target error) bool {
-	switch target.(type) {
-	case InvalidURLError, *InvalidURLError:
-		return true
-	default:
-		return false
-	}
+	return fmt.Sprint("invalid URL: ", err.URL)
 }
 
 type DuplicateError struct {
@@ -40,16 +31,7 @@ func NewDuplicateError(name string) error {
 }
 
 func (err DuplicateError) Error() string {
-	return fmt.Sprintf("repository duplicate: %s", err.Name)
-}
-
-func (DuplicateError) Is(target error) bool {
-	switch target.(type) {
-	case DuplicateError, *DuplicateError:
-		return true
-	default:
-		return false
-	}
+	return fmt.Sprint("repository duplicate: ", err.Name)
 }
 
 type NotFoundError struct {
@@ -61,14 +43,5 @@ func NewNotFoundError(name string) error {
 }
 
 func (err NotFoundError) Error() string {
-	return fmt.Sprintf("🗄 repository not found: %s", err.Name)
-}
-
-func (NotFoundError) Is(target error) bool {
-	switch target.(type) {
-	case NotFoundError, *NotFoundError:
-		return true
-	default:
-		return false
-	}
+	return fmt.Sprint("🗄 repository not found: ", err.Name)
 }
